@@ -201,21 +201,12 @@ sub _key {
     return $key;
 }
 
+sub wxwidgets_configure_extra_flags { '' }
+
 sub build_wxwidgets {
     my $self = shift;
 
-    my $extra_flags = '';
-
-    # on Snow Leopard, force wxWidgets 2.8.x builds to be 32-bit
-    if(    $Config{osname} =~ /darwin/
-         && `uname -r` =~ /^10\./
-         && `sysctl hw.cpu64bit_capable` =~ /^hw.cpu64bit_capable: 1/ ) {
-        print "Forcing wxWidgets build to 32 bit\n";
-        $extra_flags = join ' ', map { qq{$_="-arch i386"} }
-                                     qw(CFLAGS CXXFLAGS LDFLAGS
-                                        OBJCFLAGS OBJCXXFLAGS);
-    }
-
+    my $extra_flags = $self->wxwidgets_configure_extra_flags;
     my $prefix_dir = $self->_key;
     my $prefix = awx_install_arch_dir( $self, $prefix_dir );
     my $opengl = $self->notes( 'build_wx_opengl' );
@@ -241,8 +232,10 @@ sub build_wxwidgets {
     # print $cmd, "\n";
     $self->_system( $cmd ) unless -f 'Makefile';
     $self->_system( 'make all' );
-    chdir 'contrib/src/stc';
-    $self->_system( 'make all' );
+    if( $self->notes( 'build_data' )->{data}{version} !~ /^2.9/ ) {
+        chdir 'contrib/src/stc';
+        $self->_system( 'make all' );
+    }
 
     chdir $old_dir;
 }
@@ -281,8 +274,10 @@ sub install_system_wxwidgets {
 
     chdir 'bld';
     $self->_system( 'make install' . $destdir );
-    chdir 'contrib/src/stc';
-    $self->_system( 'make install' . $destdir );
+    if( $self->notes( 'build_data' )->{data}{version} !~ /^2.9/ ) {
+        chdir 'contrib/src/stc';
+        $self->_system( 'make install' . $destdir );
+    }
 
     chdir $old_dir;
 }
